@@ -1,11 +1,13 @@
 from django.db import models
 
 import form_fields
+import widgets
 
 class OpeningHoursField(models.Field):
     def formfield(self, **kwargs):
         defaults = {
             'form_class': form_fields.OpeningHoursField,
+            'widget': widgets.OpeningHoursWidget,
         }
         defaults.update(kwargs)
-        return super(self.__class__, self).formfield(**defaults)
\ No newline at end of file
+        return super(OpeningHoursField, self).formfield(**defaults)
\ No newline at end of file
